@@ -8,7 +8,6 @@
 #' published models.
 #'
 #' @name RLumModel-package
-#' @docType package
 #' @details **Authors**
 #'
 #' \tabular{ll}{
@@ -49,7 +48,7 @@
 #' @importFrom grDevices rgb
 #' @importFrom graphics axis lines mtext par rect
 #' @useDynLib RLumModel, .registration = TRUE
-NULL
+"_PACKAGE"
 
 
 #' Example data (TL curve) simulated with parameter set from Pagonis 2007
