@@ -4,9 +4,9 @@
 #'
 #' @param temp_begin \code{\link{numeric}} (\bold{required}): initial temperature [deg. C] of the TL-simulation
 #'
-#' @param temp_begin \code{\link{numeric}} (\bold{required}): endtemperature [deg. C] of the TL-simulation
+#' @param temp_begin \code{\link{numeric}} (\bold{required}): end temperature [deg. C] of the TL-simulation
 #'
-#' @param heating_rate \code{\link{numeric}} (\bold{required}): heatingrate in [deg. C/s] or [K/s]
+#' @param heating_rate \code{\link{numeric}} (\bold{required}): heating rate in [deg. C/s] or [K/s]
 #'
 #' @param n \code{\link{numeric}} or \code{\linkS4class{RLum.Results}} (\bold{required}):
 #' concentration of electron-/holetraps, valence- and conduction band
@@ -20,7 +20,7 @@
 #'
 #' @return This function returns an RLum.Results object from the heating/cooling simulation.
 #'
-#' @section Function version: 0.1.1
+#' @section Function version: 0.1.2
 #'
 #' @author Johannes Friedrich, University of Bayreuth (Germany),
 #'
@@ -46,18 +46,18 @@
 
 # check input arguments ---------------------------------------------------
 
-  ##check if heatingrate has the rigth algebraic sign
+  ##check if heatingrate has the right algebraic sign
   if((temp_begin < temp_end && heating_rate < 0)||(temp_begin > temp_end & heating_rate > 0)){
-    stop("\n [.simulate_heating()] Heatingrate has the wrong algebraic sign!")
+    stop("\n [.simulate_heating()] Heatingrate has the wrong algebraic sign!", call. = FALSE)
   }
 
-  ##check if temperature is > 0 K (-273 degree celsius)
+  ##check if temperature is > 0 K (-273 degree Celsius)
   if(temp_begin < -273 ||temp_end < -273){
-    stop("\n [.simulate_heating()] Argument 'temp' has to be > 0 K!")
+    stop("\n [.simulate_heating()] Argument 'temp' has to be > 0 K!", call. = FALSE)
   }
 
   ##check if object is of class RLum.Results
-  if(class(n) != "RLum.Results"){
+  if(!inherits(n, "RLum.Results")){
     n <- n
   } else {
     n <- n$n
