@@ -22,8 +22,6 @@
 #'
 #' @author Johannes Friedrich, University of Bayreuth (Germany),
 #'
-#' @references
-#'
 #' @seealso \code{\link{plot}}
 #'
 #' @examples
@@ -56,7 +54,7 @@
   }
 
   ##check if n is a RLum object
-  if(class(n) != "RLum.Results"){
+  if(!inherits(n, "RLum.Results")){
     n <- n
   } else {
     n <- n$n
